{% extends 'spire/base/base.html' %}

{% block base_content %}
    <div class="container-fluid">
        {% include 'spire/notification/notification.html' %}
        {% include 'spire/element/page_loading_element.html' %}

        {% block base_page_content %}
        {% endblock %}
    </div>
{% endblock %}

