{% extends 'spire/page/base_page.html' %}

{% load static %}

{% block base_page_content %}
    <div class="row justify-content-center mt-5">
        <div class="col-11 col-md-6 col-lg-4 bg-app-layer-one">
            <div class="px-4 py-5">
                <div class="text-center pb-5">
                    <a href="/">
                        <img class="ms-1 img-fluid" src="{% static 'spire/img/stratus_secondary_medium.png' %}" alt="">
                    </a>
                </div>
                {% block registration_content %}

                {% endblock %}
            </div>
        </div>
    </div>
{% endblock %}

